@@ -15,48 +15,51 @@ DBIx::Class::Async::Row - Asynchronous row object for DBIx::Class::Async
 
 =head1 VERSION
 
-Version 0.45
+Version 0.46
 
 =cut
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 =head1 SYNOPSIS
 
-    use DBIx::Class::Async::Row;
+    # Typically obtained via a ResultSet bridge
+    my $user = $rs->find(1)->get;
 
-    # Typically created by DBIx::Class::Async, not directly
-    my $row = DBIx::Class::Async::Row->new(
-        schema      => $schema,
-        async_db    => $async_db,
-        source_name => 'User',
-        row_data    => { id => 1, name => 'John', email => 'john@example.com' },
-    );
+    # Accessing Data (Synchronous/In-memory)
 
-    # Access columns
-    my $name  = $row->name;                 # Returns 'John'
-    my $email = $row->get_column('email');  # Returns 'john@example.com'
+    say "User: " . $user->name;
+    my $email = $user->get_column('email');
+    my %data  = $user->get_columns;
 
-    # Get all columns
-    my %columns = $row->get_columns;
+    # Persistence Operations (Asynchronous, returns Future)
 
-    # Update asynchronously
-    $row->update({ name => 'John Doe' })->then(sub {
-        my ($updated_row) = @_;
-        say "Updated: " . $updated_row->name;
+    # Update with chaining
+    $user->update({ last_login => time })->then(sub {
+        my $self = shift;
+        say "Update complete for: " . $self->email;
+
+        # Discard local changes and refetch fresh data from DB
+        return $self->discard_changes;
+    })->then(sub {
+        my $fresh_user = shift;
+        say "Confirmed DB state: " . $fresh_user->last_login;
     });
 
-    # Delete asynchronously
-    $row->delete->then(sub {
-        my ($success) = @_;
-        say "Deleted: " . ($success ? 'yes' : 'no');
+    # Delete record
+    $user->delete->then(sub {
+        say "Record removed from database.";
     });
 
-    # Discard changes and refetch from database
-    $row->discard_changes->then(sub {
-        my ($fresh_row) = @_;
-        # $fresh_row contains latest data from database
-    });
+    # Relationship Access (Asynchronous)
+
+    # If the Row component is loaded, access related sets
+    $user->search_related('orders', { status => 'pending' })
+         ->all
+         ->then(sub {
+             my @orders = @_;
+             say "Found " . scalar(@orders) . " pending orders.";
+         });
 
 =head1 DESCRIPTION
 
